@@ -1,7 +1,6 @@
 from pathlib import Path
 
 import click
-from click import UsageError
 
 from nuc_data_tool import __version__
 from nuc_data_tool.anomaly_detection.iforest import save_prediction_to_exel
@@ -38,7 +37,7 @@ class MutuallyExclusiveOption(click.Option):
 
     def handle_parse_result(self, ctx, opts, args):
         if self.mutually_exclusive.intersection(opts) and self.name in opts:
-            raise UsageError(
+            raise click.UsageError(
                 "Illegal usage: `{}` is mutually exclusive with "
                 "arguments `{}`.".format(
                     self.name,
@@ -279,7 +278,7 @@ def compare(reference_file,
               default=config.get_anomaly_detection_config('max_middle_steps_num'),
               type=click.INT,
               help='最大 middle_steps 长度值，默认读取配置文件中的值\n'
-                   '为None则自动读取数据库进行计算（注意：耗时极长）')
+                   '为-1则自动读取数据库进行计算（注意：耗时极长）')
 @click.option('--all_step', '-all',
               'is_all_step',
               is_flag=True,
